@@ -1,6 +1,5 @@
 use crate::fs::{Metadata, MetadataExt};
 use posish::fs::{statat, AtFlags};
-use posish::io::Errno;
 use std::{
     fs, io,
     sync::atomic::{AtomicBool, Ordering::Relaxed},
@@ -16,14 +15,14 @@ pub(super) fn file_metadata(file: &fs::File) -> io::Result<Metadata> {
     if !FSTAT_PATH_BADF.load(Relaxed) {
         match Metadata::from_file(file) {
             Ok(metadata) => return Ok(metadata),
-            Err(err) => match Errno::from_io_error(&err) {
+            Err(err) => match posish::io::Error::from_io_error(&err) {
                 // Before Linux 3.6, `fstat` with `O_PATH` returned `EBADF`.
-                Some(Errno::BADF) => FSTAT_PATH_BADF.store(true, Relaxed),
+                Some(posish::io::Error::BADF) => FSTAT_PATH_BADF.store(true, Relaxed),
                 _ => return Err(err),
             },
         }
     }
 
     // If `fstat` with `O_PATH` isn't supported, use `statat` with `AT_EMPTY_PATH`.
-    statat(file, "", AtFlags::EMPTY_PATH).map(MetadataExt::from_posish)
+    Ok(statat(file, "", AtFlags::EMPTY_PATH).map(MetadataExt::from_posish)?)
 }
