@@ -1,5 +1,4 @@
 use crate::fs::{manually, open_beneath, OpenOptions};
-use posish::io::Errno;
 use std::{ffi::OsStr, fs, io};
 
 pub(crate) fn open_entry_impl(
@@ -11,8 +10,8 @@ pub(crate) fn open_entry_impl(
 
     match result {
         Ok(file) => Ok(file),
-        Err(err) => match Errno::from_io_error(&err) {
-            Some(Errno::NOSYS) => manually::open_entry(start, path, options),
+        Err(err) => match posish::io::Error::from_io_error(&err) {
+            Some(posish::io::Error::NOSYS) => manually::open_entry(start, path, options),
             _ => Err(err),
         },
     }
